"""
Connectome Workbench

Connectome Workbench is an open source, freely available visualization and
discovery tool used to map neuroimaging data, especially data generated by the
Human Connectome Project. The distribution includes wb_view, a GUI-based
visualiation platform, and wb_command, a command-line program for performing a
variety of algorithmic tasks using volume, surface, and grayordinate data.
wb_command is necessary for running HCP data processing pipelines.

Author: Connectome Workbench Developers

URL: https://github.com/Washington-University/workbench
"""
# This file was auto generated by Styx.
# Do not edit this file directly.

from .add_to_spec_file import *
from .annotation_resample import *
from .backend_average_dense_roi import *
from .backend_average_roi_correlation import *
from .border_export_color_table import *
from .border_file_export_to_caret5 import *
from .border_length import *
from .border_merge import *
from .border_resample import *
from .border_to_rois import *
from .border_to_vertices import *
from .cifti_all_labels_to_rois import *
from .cifti_average import *
from .cifti_average_dense_roi import *
from .cifti_average_roi_correlation import *
from .cifti_change_mapping import *
from .cifti_convert import *
from .cifti_correlation import *
from .cifti_correlation_gradient import *
from .cifti_create_dense_from_template import *
from .cifti_create_dense_scalar import *
from .cifti_create_dense_timeseries import *
from .cifti_create_label import *
from .cifti_create_parcellated_from_template import *
from .cifti_create_scalar_series import *
from .cifti_cross_correlation import *
from .cifti_dilate import *
from .cifti_erode import *
from .cifti_estimate_fwhm import *
from .cifti_export_dense_mapping import *
from .cifti_extrema import *
from .cifti_false_correlation import *
from .cifti_find_clusters import *
from .cifti_gradient import *
from .cifti_label_adjacency import *
from .cifti_label_export_table import *
from .cifti_label_import import *
from .cifti_label_modify_keys import *
from .cifti_label_probability import *
from .cifti_label_to_border import *
from .cifti_label_to_roi import *
from .cifti_math import *
from .cifti_merge import *
from .cifti_merge_dense import *
from .cifti_merge_parcels import *
from .cifti_pairwise_correlation import *
from .cifti_palette import *
from .cifti_parcel_mapping_to_label import *
from .cifti_parcellate import *
from .cifti_reduce import *
from .cifti_reorder import *
from .cifti_replace_structure import *
from .cifti_resample import *
from .cifti_resample_dconn_memory import *
from .cifti_restrict_dense_map import *
from .cifti_roi_average import *
from .cifti_rois_from_extrema import *
from .cifti_separate import *
from .cifti_smoothing import *
from .cifti_stats import *
from .cifti_transpose import *
from .cifti_vector_operation import *
from .cifti_weighted_stats import *
from .convert_affine import *
from .convert_fiber_orientations import *
from .convert_matrix4_to_matrix2 import *
from .convert_matrix4_to_workbench_sparse import *
from .convert_warpfield import *
from .create_signed_distance_volume import *
from .estimate_fiber_binghams import *
from .fiber_dot_products import *
from .file_convert import *
from .file_information import *
from .foci_create import *
from .foci_get_projection_vertex import *
from .foci_list_coords import *
from .foci_resample import *
from .gifti_all_labels_to_rois import *
from .gifti_convert import *
from .gifti_label_add_prefix import *
from .gifti_label_to_roi import *
from .label_dilate import *
from .label_erode import *
from .label_export_table import *
from .label_mask import *
from .label_merge import *
from .label_modify_keys import *
from .label_probability import *
from .label_resample import *
from .label_to_border import *
from .label_to_volume_mapping import *
from .metadata_remove_provenance import *
from .metadata_string_replace import *
from .metric_convert import *
from .metric_dilate import *
from .metric_erode import *
from .metric_estimate_fwhm import *
from .metric_extrema import *
from .metric_false_correlation import *
from .metric_fill_holes import *
from .metric_find_clusters import *
from .metric_gradient import *
from .metric_label_import import *
from .metric_mask import *
from .metric_math import *
from .metric_merge import *
from .metric_palette import *
from .metric_reduce import *
from .metric_regression import *
from .metric_remove_islands import *
from .metric_resample import *
from .metric_rois_from_extrema import *
from .metric_rois_to_border import *
from .metric_smoothing import *
from .metric_stats import *
from .metric_tfce import *
from .metric_to_volume_mapping import *
from .metric_vector_operation import *
from .metric_vector_toward_roi import *
from .metric_weighted_stats import *
from .nifti_information import *
from .probtrackx_dot_convert import *
from .scene_capture_image import *
from .scene_file_merge import *
from .scene_file_relocate import *
from .scene_file_update import *
from .set_map_names import *
from .set_structure import *
from .signed_distance_to_surface import *
from .spec_file_merge import *
from .spec_file_relocate import *
from .surface_affine_regression import *
from .surface_apply_affine import *
from .surface_apply_warpfield import *
from .surface_average import *
from .surface_closest_vertex import *
from .surface_coordinates_to_metric import *
from .surface_cortex_layer import *
from .surface_create_sphere import *
from .surface_curvature import *
from .surface_cut_resample import *
from .surface_distortion import *
from .surface_flip_lr import *
from .surface_flip_normals import *
from .surface_generate_inflated import *
from .surface_geodesic_distance import *
from .surface_geodesic_distance_all_to_all import *
from .surface_geodesic_rois import *
from .surface_inflation import *
from .surface_information import *
from .surface_match import *
from .surface_modify_sphere import *
from .surface_normals import *
from .surface_resample import *
from .surface_set_coordinates import *
from .surface_smoothing import *
from .surface_sphere_project_unproject import *
from .surface_sphere_triangular_patches import *
from .surface_to_surface_3d_distance import *
from .surface_vertex_areas import *
from .surface_wedge_volume import *
from .volume_all_labels_to_rois import *
from .volume_capture_plane import *
from .volume_components_to_frames import *
from .volume_copy_extensions import *
from .volume_create import *
from .volume_dilate import *
from .volume_distortion import *
from .volume_erode import *
from .volume_estimate_fwhm import *
from .volume_extrema import *
from .volume_fill_holes import *
from .volume_find_clusters import *
from .volume_gradient import *
from .volume_label_export_table import *
from .volume_label_import import *
from .volume_label_modify_keys import *
from .volume_label_probability import *
from .volume_label_to_roi import *
from .volume_label_to_surface_mapping import *
from .volume_math import *
from .volume_merge import *
from .volume_palette import *
from .volume_parcel_resampling import *
from .volume_parcel_resampling_generic import *
from .volume_parcel_smoothing import *
from .volume_reduce import *
from .volume_remove_islands import *
from .volume_reorient import *
from .volume_resample import *
from .volume_rois_from_extrema import *
from .volume_set_space import *
from .volume_smoothing import *
from .volume_stats import *
from .volume_tfce import *
from .volume_to_surface_mapping import *
from .volume_vector_operation import *
from .volume_warpfield_affine_regression import *
from .volume_weighted_stats import *
from .wbsparse_merge_dense import *
from .zip_scene_file import *
from .zip_spec_file import *
from styxdefs import Runner as _Runner


def execute(
    params: dict,
    runner: _Runner | None = None,
) -> None:
    """
    Run a command in this package dynamically from a params object.
    
    Args:
        params: The parameters.
        runner: Command runner.
    """
    return {
        "workbench/add-to-spec-file": add_to_spec_file_execute,
        "workbench/annotation-resample": annotation_resample_execute,
        "workbench/backend-average-dense-roi": backend_average_dense_roi_execute,
        "workbench/backend-average-roi-correlation": backend_average_roi_correlation_execute,
        "workbench/border-export-color-table": border_export_color_table_execute,
        "workbench/border-file-export-to-caret5": border_file_export_to_caret5_execute,
        "workbench/border-length": border_length_execute,
        "workbench/border-merge": border_merge_execute,
        "workbench/border-resample": border_resample_execute,
        "workbench/border-to-rois": border_to_rois_execute,
        "workbench/border-to-vertices": border_to_vertices_execute,
        "workbench/cifti-all-labels-to-rois": cifti_all_labels_to_rois_execute,
        "workbench/cifti-average-dense-roi": cifti_average_dense_roi_execute,
        "workbench/cifti-average-roi-correlation": cifti_average_roi_correlation_execute,
        "workbench/cifti-average": cifti_average_execute,
        "workbench/cifti-change-mapping": cifti_change_mapping_execute,
        "workbench/cifti-convert": cifti_convert_execute,
        "workbench/cifti-correlation-gradient": cifti_correlation_gradient_execute,
        "workbench/cifti-correlation": cifti_correlation_execute,
        "workbench/cifti-create-dense-from-template": cifti_create_dense_from_template_execute,
        "workbench/cifti-create-dense-scalar": cifti_create_dense_scalar_execute,
        "workbench/cifti-create-dense-timeseries": cifti_create_dense_timeseries_execute,
        "workbench/cifti-create-label": cifti_create_label_execute,
        "workbench/cifti-create-parcellated-from-template": cifti_create_parcellated_from_template_execute,
        "workbench/cifti-create-scalar-series": cifti_create_scalar_series_execute,
        "workbench/cifti-cross-correlation": cifti_cross_correlation_execute,
        "workbench/cifti-dilate": cifti_dilate_execute,
        "workbench/cifti-erode": cifti_erode_execute,
        "workbench/cifti-estimate-fwhm": cifti_estimate_fwhm_execute,
        "workbench/cifti-export-dense-mapping": cifti_export_dense_mapping_execute,
        "workbench/cifti-extrema": cifti_extrema_execute,
        "workbench/cifti-false-correlation": cifti_false_correlation_execute,
        "workbench/cifti-find-clusters": cifti_find_clusters_execute,
        "workbench/cifti-gradient": cifti_gradient_execute,
        "workbench/cifti-label-adjacency": cifti_label_adjacency_execute,
        "workbench/cifti-label-export-table": cifti_label_export_table_execute,
        "workbench/cifti-label-import": cifti_label_import_execute,
        "workbench/cifti-label-modify-keys": cifti_label_modify_keys_execute,
        "workbench/cifti-label-probability": cifti_label_probability_execute,
        "workbench/cifti-label-to-border": cifti_label_to_border_execute,
        "workbench/cifti-label-to-roi": cifti_label_to_roi_execute,
        "workbench/cifti-math": cifti_math_execute,
        "workbench/cifti-merge-dense": cifti_merge_dense_execute,
        "workbench/cifti-merge-parcels": cifti_merge_parcels_execute,
        "workbench/cifti-merge": cifti_merge_execute,
        "workbench/cifti-pairwise-correlation": cifti_pairwise_correlation_execute,
        "workbench/cifti-palette": cifti_palette_execute,
        "workbench/cifti-parcel-mapping-to-label": cifti_parcel_mapping_to_label_execute,
        "workbench/cifti-parcellate": cifti_parcellate_execute,
        "workbench/cifti-reduce": cifti_reduce_execute,
        "workbench/cifti-reorder": cifti_reorder_execute,
        "workbench/cifti-replace-structure": cifti_replace_structure_execute,
        "workbench/cifti-resample-dconn-memory": cifti_resample_dconn_memory_execute,
        "workbench/cifti-resample": cifti_resample_execute,
        "workbench/cifti-restrict-dense-map": cifti_restrict_dense_map_execute,
        "workbench/cifti-roi-average": cifti_roi_average_execute,
        "workbench/cifti-rois-from-extrema": cifti_rois_from_extrema_execute,
        "workbench/cifti-separate": cifti_separate_execute,
        "workbench/cifti-smoothing": cifti_smoothing_execute,
        "workbench/cifti-stats": cifti_stats_execute,
        "workbench/cifti-transpose": cifti_transpose_execute,
        "workbench/cifti-vector-operation": cifti_vector_operation_execute,
        "workbench/cifti-weighted-stats": cifti_weighted_stats_execute,
        "workbench/convert-affine": convert_affine_execute,
        "workbench/convert-fiber-orientations": convert_fiber_orientations_execute,
        "workbench/convert-matrix4-to-matrix2": convert_matrix4_to_matrix2_execute,
        "workbench/convert-matrix4-to-workbench-sparse": convert_matrix4_to_workbench_sparse_execute,
        "workbench/convert-warpfield": convert_warpfield_execute,
        "workbench/create-signed-distance-volume": create_signed_distance_volume_execute,
        "workbench/estimate-fiber-binghams": estimate_fiber_binghams_execute,
        "workbench/fiber-dot-products": fiber_dot_products_execute,
        "workbench/file-convert": file_convert_execute,
        "workbench/file-information": file_information_execute,
        "workbench/foci-create": foci_create_execute,
        "workbench/foci-get-projection-vertex": foci_get_projection_vertex_execute,
        "workbench/foci-list-coords": foci_list_coords_execute,
        "workbench/foci-resample": foci_resample_execute,
        "workbench/gifti-all-labels-to-rois": gifti_all_labels_to_rois_execute,
        "workbench/gifti-convert": gifti_convert_execute,
        "workbench/gifti-label-add-prefix": gifti_label_add_prefix_execute,
        "workbench/gifti-label-to-roi": gifti_label_to_roi_execute,
        "workbench/label-dilate": label_dilate_execute,
        "workbench/label-erode": label_erode_execute,
        "workbench/label-export-table": label_export_table_execute,
        "workbench/label-mask": label_mask_execute,
        "workbench/label-merge": label_merge_execute,
        "workbench/label-modify-keys": label_modify_keys_execute,
        "workbench/label-probability": label_probability_execute,
        "workbench/label-resample": label_resample_execute,
        "workbench/label-to-border": label_to_border_execute,
        "workbench/label-to-volume-mapping": label_to_volume_mapping_execute,
        "workbench/metadata-remove-provenance": metadata_remove_provenance_execute,
        "workbench/metadata-string-replace": metadata_string_replace_execute,
        "workbench/metric-convert": metric_convert_execute,
        "workbench/metric-dilate": metric_dilate_execute,
        "workbench/metric-erode": metric_erode_execute,
        "workbench/metric-estimate-fwhm": metric_estimate_fwhm_execute,
        "workbench/metric-extrema": metric_extrema_execute,
        "workbench/metric-false-correlation": metric_false_correlation_execute,
        "workbench/metric-fill-holes": metric_fill_holes_execute,
        "workbench/metric-find-clusters": metric_find_clusters_execute,
        "workbench/metric-gradient": metric_gradient_execute,
        "workbench/metric-label-import": metric_label_import_execute,
        "workbench/metric-mask": metric_mask_execute,
        "workbench/metric-math": metric_math_execute,
        "workbench/metric-merge": metric_merge_execute,
        "workbench/metric-palette": metric_palette_execute,
        "workbench/metric-reduce": metric_reduce_execute,
        "workbench/metric-regression": metric_regression_execute,
        "workbench/metric-remove-islands": metric_remove_islands_execute,
        "workbench/metric-resample": metric_resample_execute,
        "workbench/metric-rois-from-extrema": metric_rois_from_extrema_execute,
        "workbench/metric-rois-to-border": metric_rois_to_border_execute,
        "workbench/metric-smoothing": metric_smoothing_execute,
        "workbench/metric-stats": metric_stats_execute,
        "workbench/metric-tfce": metric_tfce_execute,
        "workbench/metric-to-volume-mapping": metric_to_volume_mapping_execute,
        "workbench/metric-vector-operation": metric_vector_operation_execute,
        "workbench/metric-vector-toward-roi": metric_vector_toward_roi_execute,
        "workbench/metric-weighted-stats": metric_weighted_stats_execute,
        "workbench/nifti-information": nifti_information_execute,
        "workbench/probtrackx-dot-convert": probtrackx_dot_convert_execute,
        "workbench/scene-capture-image": scene_capture_image_execute,
        "workbench/scene-file-merge": scene_file_merge_execute,
        "workbench/scene-file-relocate": scene_file_relocate_execute,
        "workbench/scene-file-update": scene_file_update_execute,
        "workbench/set-map-names": set_map_names_execute,
        "workbench/set-structure": set_structure_execute,
        "workbench/signed-distance-to-surface": signed_distance_to_surface_execute,
        "workbench/spec-file-merge": spec_file_merge_execute,
        "workbench/spec-file-relocate": spec_file_relocate_execute,
        "workbench/surface-affine-regression": surface_affine_regression_execute,
        "workbench/surface-apply-affine": surface_apply_affine_execute,
        "workbench/surface-apply-warpfield": surface_apply_warpfield_execute,
        "workbench/surface-average": surface_average_execute,
        "workbench/surface-closest-vertex": surface_closest_vertex_execute,
        "workbench/surface-coordinates-to-metric": surface_coordinates_to_metric_execute,
        "workbench/surface-cortex-layer": surface_cortex_layer_execute,
        "workbench/surface-create-sphere": surface_create_sphere_execute,
        "workbench/surface-curvature": surface_curvature_execute,
        "workbench/surface-cut-resample": surface_cut_resample_execute,
        "workbench/surface-distortion": surface_distortion_execute,
        "workbench/surface-flip-lr": surface_flip_lr_execute,
        "workbench/surface-flip-normals": surface_flip_normals_execute,
        "workbench/surface-generate-inflated": surface_generate_inflated_execute,
        "workbench/surface-geodesic-distance-all-to-all": surface_geodesic_distance_all_to_all_execute,
        "workbench/surface-geodesic-distance": surface_geodesic_distance_execute,
        "workbench/surface-geodesic-rois": surface_geodesic_rois_execute,
        "workbench/surface-inflation": surface_inflation_execute,
        "workbench/surface-information": surface_information_execute,
        "workbench/surface-match": surface_match_execute,
        "workbench/surface-modify-sphere": surface_modify_sphere_execute,
        "workbench/surface-normals": surface_normals_execute,
        "workbench/surface-resample": surface_resample_execute,
        "workbench/surface-set-coordinates": surface_set_coordinates_execute,
        "workbench/surface-smoothing": surface_smoothing_execute,
        "workbench/surface-sphere-project-unproject": surface_sphere_project_unproject_execute,
        "workbench/surface-sphere-triangular-patches": surface_sphere_triangular_patches_execute,
        "workbench/surface-to-surface-3d-distance": surface_to_surface_3d_distance_execute,
        "workbench/surface-vertex-areas": surface_vertex_areas_execute,
        "workbench/surface-wedge-volume": surface_wedge_volume_execute,
        "workbench/volume-all-labels-to-rois": volume_all_labels_to_rois_execute,
        "workbench/volume-capture-plane": volume_capture_plane_execute,
        "workbench/volume-components-to-frames": volume_components_to_frames_execute,
        "workbench/volume-copy-extensions": volume_copy_extensions_execute,
        "workbench/volume-create": volume_create_execute,
        "workbench/volume-dilate": volume_dilate_execute,
        "workbench/volume-distortion": volume_distortion_execute,
        "workbench/volume-erode": volume_erode_execute,
        "workbench/volume-estimate-fwhm": volume_estimate_fwhm_execute,
        "workbench/volume-extrema": volume_extrema_execute,
        "workbench/volume-fill-holes": volume_fill_holes_execute,
        "workbench/volume-find-clusters": volume_find_clusters_execute,
        "workbench/volume-gradient": volume_gradient_execute,
        "workbench/volume-label-export-table": volume_label_export_table_execute,
        "workbench/volume-label-import": volume_label_import_execute,
        "workbench/volume-label-modify-keys": volume_label_modify_keys_execute,
        "workbench/volume-label-probability": volume_label_probability_execute,
        "workbench/volume-label-to-roi": volume_label_to_roi_execute,
        "workbench/volume-label-to-surface-mapping": volume_label_to_surface_mapping_execute,
        "workbench/volume-math": volume_math_execute,
        "workbench/volume-merge": volume_merge_execute,
        "workbench/volume-palette": volume_palette_execute,
        "workbench/volume-parcel-resampling-generic": volume_parcel_resampling_generic_execute,
        "workbench/volume-parcel-resampling": volume_parcel_resampling_execute,
        "workbench/volume-parcel-smoothing": volume_parcel_smoothing_execute,
        "workbench/volume-reduce": volume_reduce_execute,
        "workbench/volume-remove-islands": volume_remove_islands_execute,
        "workbench/volume-reorient": volume_reorient_execute,
        "workbench/volume-resample": volume_resample_execute,
        "workbench/volume-rois-from-extrema": volume_rois_from_extrema_execute,
        "workbench/volume-set-space": volume_set_space_execute,
        "workbench/volume-smoothing": volume_smoothing_execute,
        "workbench/volume-stats": volume_stats_execute,
        "workbench/volume-tfce": volume_tfce_execute,
        "workbench/volume-to-surface-mapping": volume_to_surface_mapping_execute,
        "workbench/volume-vector-operation": volume_vector_operation_execute,
        "workbench/volume-warpfield-affine-regression": volume_warpfield_affine_regression_execute,
        "workbench/volume-weighted-stats": volume_weighted_stats_execute,
        "workbench/wbsparse-merge-dense": wbsparse_merge_dense_execute,
        "workbench/zip-scene-file": zip_scene_file_execute,
        "workbench/zip-spec-file": zip_spec_file_execute,
    }[params["@type"]](params, runner)
